<?php

namespace Drupal\Tests\build_hooks\Kernel;

use Drupal\build_hooks\Entity\FrontendEnvironment;
use Drupal\build_hooks\Trigger;
use Drupal\entity_test\Entity\EntityTest;
use Drupal\KernelTests\KernelTestBase;

/**
 * Tests behaviour of the config-entity + plugin system.
 *
 * @group build_hooks
 */
class BuildHooksConfigEntityTest extends KernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'build_hooks',
    'dblog',
    'views',
    'build_hooks_test',
    'system',
    'user',
    'entity_test',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();
    $this->installSchema('dblog', ['watchdog']);
    $this->installConfig('build_hooks');
    $this->installEntitySchema('entity_test');
    $this->config('build_hooks.settings')->set('logging.entity_types', ['entity_test' => 'entity_test'])->save();
  }

  /**
   * Tests the config-entity.
   */
  public function testFrontendEnvironment() {
    $title = $this->randomMachineName();
    $environment = FrontendEnvironment::create([
      'id' => 'foo',
      'label' => $title,
      'settings' => [
        'whiz' => 'bar',
      ],
      'plugin' => 'build_hooks_test',
      'provider' => 'build_hooks_test',
      'deployment_strategy' => Trigger::DEPLOYMENT_STRATEGY_ENTITYSAVE,
    ]);
    $environment->save();
    $this->assertEquals($title, $environment->label());
    $entity = EntityTest::create([
      'name' => $this->randomMachineName(),
    ]);
    $entity->save();
  }

}
